#
# spec file for package multipath-tools
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           multipath-tools
BuildRequires:  device-mapper-devel libaio-devel readline-devel
Url:            http://christophe.varoqui.free.fr/
License:        BSD3c(or similar) ; GPLv2+ ; LGPLv2.1+ ; Public Domain, Freeware ; MIT License (or similar)
Group:          System/Base
Requires:       device-mapper kpartx
Requires:       coreutils grep
AutoReqProv:    on
Version:        0.4.8
Release:        65.1.3
Summary:        Tools to Manage Multipathed Devices with the device-mapper
Source:         multipath-tools-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch0:         %{name}-%{version}-opensuse-11.3.diff.bz2
Patch1:         multipath-tools-0.4.8-asneeded.patch

%description
This package provides the tools to manage multipathed devices by
instructing the device-mapper multipath module what to do. The tools
are:

- multipath: scans the system for multipathed devices, assembles
   them, and updates the device-mapper's maps

- multipathd: waits for maps events then execs multipath

- devmap-name: provides a meaningful device name to udev for devmaps

- kpartx: maps linear devmaps to device partitions, which makes
multipath maps partionable



Authors:
--------
    Christophe Varoqui <christophe.varoqui@free.fr>

%package -n kpartx
License:        BSD3c(or similar) ; GPLv2+ ; LGPLv2.1+ ; Public Domain, Freeware ; MIT License (or similar)
Summary:        Manages partition tables on device-mapper devices
Group:          System/Base
Requires:       device-mapper

%description -n kpartx
The kpartx program maps linear devmaps to device partitions, which
makes multipath maps partionable.



Authors:
--------
    Christophe Varoqui <christophe.varoqui@free.fr>

%prep
%setup -q -n multipath-tools-%{version}
%patch0 -p1
%patch1

%build
make CC="%__cc" OPTFLAGS="$RPM_OPT_FLAGS" LIB=%_lib

%install
make DESTDIR=$RPM_BUILD_ROOT LIB=%_lib install
mkdir -p $RPM_BUILD_ROOT/var/cache/multipath/

%clean
[ "$RPM_BUILD_ROOT" != / ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;

%pre
[ -f /.buildenv ] && exit 0
if [ -f /etc/init.d/multipathd ] && dmsetup --target multipath table | grep -q multipath ; then
    /etc/init.d/multipathd stop
fi

%post
[ -f /.buildenv ] && exit 0
if dmsetup --target multipath table | grep -q multipath ; then
    /etc/init.d/multipathd start
fi
[ -x /sbin/mkinitrd_setup ] && mkinitrd_setup
exit 0
#{insserv /etc/init.d/multipathd}
#{fillup_and_insserv boot.multipath}

%preun
%stop_on_removal multipathd

%postun
[ -x /sbin/mkinitrd_setup ] && mkinitrd_setup
%{insserv_cleanup}

%files
%defattr(-,root,root)
%doc AUTHOR COPYING README ChangeLog 
%doc multipath.conf*
%dir /etc/udev
%dir /etc/udev/rules.d
%config /etc/init.d/multipathd
%config /etc/init.d/boot.multipath
%config /etc/udev/rules.d/71-multipath.rules
/%{_lib}/libmultipath.so.0
/%{_lib}/multipath
/sbin/multipath
/sbin/multipathd
%attr (0700, root, root) /var/cache/multipath
%dir /lib/mkinitrd
%dir /lib/mkinitrd/scripts
/lib/mkinitrd/scripts/boot-multipath.sh
/lib/mkinitrd/scripts/setup-multipath.sh
%{_mandir}/man8/multipath.8*
%{_mandir}/man5/multipath.conf.5*
%{_mandir}/man8/multipathd.8*

%files -n kpartx
%defattr(-,root,root)
%dir /etc/udev
%dir /etc/udev/rules.d
%config /etc/udev/rules.d/70-kpartx.rules
/sbin/kpartx
/sbin/activate_dm_linear
%dir /lib/udev
/lib/udev/kpartx_id
%dir /lib/mkinitrd
%dir /lib/mkinitrd/scripts
/lib/mkinitrd/scripts/boot-kpartx.sh
/lib/mkinitrd/scripts/setup-kpartx.sh
%{_mandir}/man8/kpartx.8*

%changelog
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Fri May 27 2011 lnussel@suse.de
- don't hard require boot.device-mapper in boot.multipath. dm-mod is
  autoloaded when accessing /dev/mapper/control anyways.
* Mon Apr  4 2011 crrodriguez@opensuse.org
- fix build fail with AS_NEEDED by default
* Fri Nov 26 2010 meissner@suse.de
- updated one more dm_simplecmd caller with &cookie.
- bumped 1 character buffer to 1 byte more for leading \0
* Tue Jul  6 2010 hare@suse.de
- Merge with fixes from mainline.
* Wed Jun 30 2010 jengelh@medozas.de
- fix compilation on bi-arch by specifying LIB=%%_lib
  (Makefiles would erroneously assume a 64-bit target just by the
  sheer presence of lib64, which is wrong)
- always add in -D_GNU_SOURCE to get at struct ucred
* Wed Jun 23 2010 hare@suse.de
- Increase initial timeout for 'tur' checker (bnc#616694)
* Fri Jun 18 2010 hare@suse.de
- Set geometry information for multipath maps (bnc#613363)
- Reset 'running' parameter for directio (bnc#600043)
- Add fallback to init script for older versions (bnc#602957)
* Fri Jun  4 2010 hare@suse.de
- Add HP 2000 to internal hardware table (bnc#603359)
- Make path state messages unique
- Add 'reassign_maps' configuration parameter
- Profiling fixes:
  * Update 'max_fds' handling
  * Use strcmp() instead of strcmp_chomp()
  * Simplify sysfs_get_device()
  * Remove duplicate calls to path_offline()
  * Simplify dm_get_name()
  * Fixup devt2devname()
  * Rework dm_reassign()
- check argument length in execute_program(bnc#610914)
- Do not use LOG_CONS when opening syslog (bnc#610914)
- Remove pid file usage from init scripts (bnc#600412)
- Fixup boot.multipath init script (bnc#600412)
* Wed May 12 2010 hare@suse.de
- Always provide symlinks for udev (bnc#603785)
* Thu May  6 2010 hare@suse.de
- Use minor number in ev_remove_map() (bnc#599770)
- signal_waiter() overwrites structure (bnc#591399)
- Serialize startup on large machines (bnc#598697)
- Update multipath(8) manpage for '-p' (bnc#602970)
- Mark 'readsector0' checker as deprecated (bnc#589340)
* Mon Apr 26 2010 hare@suse.de
- Errorneous message 'error starting uevent listener'
- Graceful shutdown of logging thread (bnc#591399)
* Mon Apr 26 2010 hare@suse.de
- Missing '-p' option for mkdir in mkinitrd script (bnc#597786)
- rdac message not printed correctly (bnc#598302)
- Use alias when printing log messages (bnc#598302)
- valgrind fixes (bnc#591399)
- Use VECTOR_SIZE() defines
- Update hwtable factorization
- Use log_close() on shutdown
- Use refcounting for checkers (bnc#591399)
- More valgrind fixes
* Tue Apr 20 2010 hare@suse.de
- Provide correct persistent symlinks for user_friendly_names
  (bnc#596301)
- Fixup hardware table for LSI arrays (bnc#597713)
- Reassign maps during startup (bnc#586834)
- Update manpage
* Tue Apr 20 2010 mmarek@suse.cz
- Use mkdir -p in mkinitrd setup script (bnc#597786).
* Fri Apr  9 2010 hare@suse.de
- Remove 'minor' argument from add_map_without_path
- Check for correct device-mapper device in uevent handler
- Start uevent service handler from main thread
- Do not reassign multipath maps (bnc#594341)
- Protect waiter structure by mutex (bnc#581200)
- Log directly to syslog on shutdown (bnc#581200)
- Clear up uevent queue on shutdown
- Add more IBM/FAStT arrays (bnc#578738)
* Mon Mar 29 2010 hare@suse.de
- Display average priority as group priority (bnc#588591)
- Implement 'wait event' cli command (bnc#586834)
- Reset existing maps (bnc#577894)
* Mon Mar 15 2010 hare@suse.de
- Setup 'checkint' when loading config file (bnc#586847)
* Wed Mar 10 2010 hare@suse.de
- Fix typo in persistent rules for by-label/by-uuid
- Update debug string in verify_paths()
- Evaluate feature setting in verify_paths() (bnc#584197)
* Fri Mar  5 2010 hare@suse.de
- Fixup 'async_timeout' initialization again (bnc#580413)
* Fri Feb 26 2010 coolo@novell.com
- fix buffer overflow in strncat
* Mon Feb 22 2010 hare@suse.de
- 'reset log' cli command crashes daemon (bnc#577889)
- Initialize 'async_timeout' variable correctly (bnc#580413)
* Thu Feb  4 2010 hare@suse.de
- Add hardware defaults for EMC Invista (bnc#573870)
- Use '--replace-whitespace' for scsi_id (bnc#572209)
- Asynchronous mode for tur checker (bnc#552688)
- Update queue_if_no_path after sync with kernel state
  (bnc#570932)
- Add 'max_polling_interval' config variable (bnc#570932)
- Add 'async_timeout' configuration variable (bnc#570932)
- Use default scsi_id callout for EMC Symmetrix (bnc#528481)
- Update path_offline() to return device status
- Update filename in init script
- Fixes from upstream:
  * do not allow 0 size for multipath devices
  * Add nexenta comstart hardware defaults
  * Add checks for conf->xxx
  * Add %%z wildcard to display path serial
  * don't pretend config file has setup parameters
  * documentation fixes
* Mon Jan 25 2010 hare@suse.de
- Fixup kpartx initrd script to handle loop devices (bnc#523749)
- Switch off 'queue_if_no_path' before removing maps (bnc#475523)
- Update logical partition handling (bnc#551827)
* Fri Jan 22 2010 hare@suse.de
- Fix mkinitrd scripts for 64bit (bnc572143)
- Remove logical partitions maps with 'multipath -f'
* Fri Jan 22 2010 ro@suse.de
- testing for existence of /lib64 is not sufficient to find out
  if we are building for a lib64 platform
* Mon Jan 11 2010 hare@suse.de
- Update dev_loss_tmo for no_path_retry (bnc#492469)
* Tue Nov 17 2009 hare@suse.de
- Merge in changes from OpenSUSE 11.2
- Update 'no_path_retry' correctly for failed paths (bnc#534666)
- Update no_path_retry setting when evaluating features (bnc#542145)
- directio: block count calculation wrong (bnc#549028)
- multipath segfaults if configuration file contains errors
  (bnc#540118)
* Thu Oct 22 2009 hare@suse.de
- Make 'param' local (bnc#548708)
- Include multipath-fix.patch in git tree.
* Mon Sep 28 2009 hare@suse.de
- Fixup strip whitespaces from getuid output (bnc#542085)
- Change prefix for DASD devices to 'ccw'
- Update no_path_retry setting when evaluating features (bnc#542145)
* Wed Sep 16 2009 hare@suse.de
- Update features when queue_if_no_path is set (bnc#511607)
- Ignore error messages when multipathd is not started
- Add debugging output for feature changes
- Add generic LSI/Engenio controller (bnc#508030)
- Update 'no_path_retry' correctly for failed paths (bnc#534666)
- TUR checker should not return 'failed' for reservation conflict
  (bnc#498413)
* Tue Sep  8 2009 aj@suse.de
- Fix last patch, one caller of dm_simplecmd was not updated
  (multipath-fix.patch).
* Fri Aug 21 2009 hare@suse.de
- Update to latest upstream git version
- Merge in SLES11 fixes
- Build package from git tree
- Implement '-u' option for kpartx (bnc#517442)
* Mon Jul 13 2009 hare@suse.de
- Check for errors in pthread_create()
- Lock vectors during shutdown
- Cleanup various MALLOC/REALLOC callers
- Fix multipathd crash on shutdown
- Do not run kpartx on dm-uevent messages (bnc#473352)
- Set pthread stacksize correctly (bnc#485287)
- Add STK arrays to internal hardware table (bnc#503855)
- Correct persistent symlink for cciss (bnc#497997)
- Backport some fixes from upstream (bnc#445023)
- Add 'reset log' cli command
- no_path_retry <N> causes I/O to fail (bnc#485281)
- Terminate uevent service queue
- Wait for daemon to shutdown (bnc#481389)
- Update cli request processing
- Safe memory allocation in cli_handlers
- Use 'LOG_CONS' option for openlog()
- Remove sysfs attribute cache
- Add 'shutdown' cli command
- Display FC error messages correctly
- Wait for devices in init script (bnc#487586)
- Always synchronize with dm state (bnc#447887)
- Add 'aas' path prioritizer (bnc#472069)
- Synchronize daemon startup with init file (bnc#481389)
- Merge feature string in assemble_map (bnc#507793)
  - ------------------------------------------------------------------
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Fri Mar 20 2009 hare@suse.de
- Reset checker message for blocked checkers
- Increase priority for EMC Clariion arrays (bnc#484529)
- Start waiter threads for single paths correctly (bnc#473841)
- Use pthread_sigmask in alias.c when called from daemon.
* Thu Mar 19 2009 hare@suse.de
- Add %%pre and %%post scripts to stop multipathd during update
- Don't set FC parameter on non-SCSI devices
- multipath -t crashes with invalid configuration file
* Fri Mar 13 2009 hare@suse.de
- Don't remove partition mappings on stop (bnc#468826)
- Set stacksize for log thread
- Terminate all I/O before flushing maps (bnc#475523)
- Select 'features' keyword from multipath setting (bnc#465009)
* Tue Mar 10 2009 hare@suse.de
- Use lists for uevent processing (bnc#478874)
- Set stacksize of uevent handling thread (bnc#478874)
- Increase uevent buffer size
- Strip trailing blanks from wwid
- Stack overflow in uev_trigger (bnc#476540)
* Thu Feb 26 2009 hare@suse.de
- Fixup multibus zero path handling (bnc#476330)
- Update checker handling for blocked devices
- Only pass block events to multipathd
- Clean up uevent processing (bnc#478874)
- Set stacksize correctly for event processing thread (bnc#478874)
* Mon Feb 23 2009 hare@suse.de
- Remove stray umask() call (bnc#458598)
- Don't call kpartx if no paths are active (bnc#473352)
* Thu Feb 19 2009 hare@suse.de
- Multipathd dies immediately after startup (bnc#473029)
- Return ghost state if port is in standby (bnc#475816)
- Switch off queue_if_no_path before removing paths (bnc#475523)
* Mon Feb  9 2009 hare@suse.de
- Fix leastpending loadbalancer output (bnc#444199)
- Start waitevent checker on new paths (bnc#473841)
- Use 'noflush' for kpartx (bnc#473352)
* Fri Feb  6 2009 hare@suse.de
- Display multipath output for leastpending loadbalancer
  properly (bnc#444199)
* Wed Feb  4 2009 hare@suse.de
- Set queue_if_no_path setting during map reload (bnc#472253)
- Remove obsolete 'umount map' uevent handling
- Retry TUR on driver errors (bnc#456961)
* Tue Feb  3 2009 hare@suse.de
- Copy persistent bindings file into initramfs (bnc#468804)
- Invert DM_STATE check for kpartx rules (bnc#440959)
* Mon Feb  2 2009 hare@suse.de
- Correct dbg_malloc() definition
- Fix more memory leaks
- Double free on path release (bnc#458393)
* Mon Jan 26 2009 hare@suse.de
- Don't access blocked devices in checkerloop()
- Check for validity in VECTOR_XXX defines (bnc#469269,bnc#457465)
* Fri Jan 23 2009 hare@suse.de
- Update dev_loss_tmo handling (bnc#458393)
- Fix directio error messages
- Update sdev_state handling
* Mon Jan 19 2009 hare@suse.de
- Add new HP machines to hardware table (bnc#442133)
- Print device-mapper tables for debugging
- Properly quote variables in mkinitrd scripts (bnc#447966)
- shuffle call to memarea_init
- Add xdr_setsite in init scripts (bnc#459529)
* Tue Jan 13 2009 hare@suse.de
- Do not run checkers or prioritizers on blocked devices
  (bnc#464155)
- Implement dev_loss_tmo and fast_io_fail_tmo (bnc#464155)
- Use default values for dev_loss_tmo and fast_io_fail_tmo
- Display checker and prio name on failure
- Add more debugging output
* Mon Jan 12 2009 hare@suse.de
- Set max_fds setting for multipath (bnc#457443)
- Enhance error messages for checker and prio loading (bnc#456214)
- Fix merge errors for prio_weightedpath (bnc#441007)
- Fix sysfs_attr_get_value (bnc#456747)
- Do not reinitialize prio and checker lists after config file
  has been parsed (bnc#464373)
- Minor cleanups
* Thu Dec  4 2008 hare@suse.de
- Split off IBM ESS hwtable entries (bnc#439763)
- Reload map when device R/O setting changes (bnc#440959)
* Fri Nov 21 2008 hare@suse.de
- Add 'Weighted Paths' prioritizer (bnc#441007)
- Fix crashes in update_multipath
* Thu Nov 20 2008 hare@suse.de
- Valgrind fixes
  * Add missing initialisation
  * Always allocate memory for alias
  * Check return value of basename
- Adapt to new sysfs layout (bnc#435215, bnc#445041)
- Use /sys/dev to speedup reverse lookups
- Rework sysfs device handling (bnc#435215, bnc#438031)
- Search for correct hardware entry during reconfigure (bnc#435688)
- Use local variables for device mapper params
- Allow zero paths for multipath maps
* Mon Nov 17 2008 hare@suse.de
- Update HP hardware table (bnc#442133)
- Zero out lines in print.c (bnc#445023)
* Mon Nov 10 2008 hare@suse.de
- Check for empty mpvecs in mpvec_garbage_collector() (bnc#437245)
- dmraid uuid starts with 'DMRAID' (bnc#439439)
- Handle arguments to multipathd from the init file
* Thu Nov  6 2008 ro@suse.de
- commenting multiline rpm macros is dangerous (read broken)
  remove percent sign in commented macro lines
* Mon Nov  3 2008 hare@suse.de
- Use pthread_join() during shutdown to avoid crash (bnc#437245)
- Fixup '%%n' to handle '!' kernel device name syntax (bnc#435172)
- Use correct commandline for cciss scsi_id callouts (bnc#435172)
- Do not check for valid mp context in get_state() (bnc#433659)
- Link directio checker against libaio (bnc#433659)
- Use regmatch when checking for duplicates in hwtable (bnc#439763)
* Mon Oct 27 2008 hare@suse.de
- Patches from mainline:
  * Increase bindings file lock timeout
  * Fixes for 'show paths format'
  * Add 'show wildcards' cli cmd
  * Add support for IBM storage devices
- fopen() returns NULL on failure (bnc#432598)
- Read verbosity level from configuration file (bnc#388284)
- kpartx -l does not remove it's loop device (bnc#417266)
- Missing fixes for libprio ontap.c (bnc#426975)
- Increase buffer size in find_loop_by_file (bnc#436428)
- Include SCSI device handler modules for initrd (bnc#431877)
* Fri Sep 26 2008 hare@suse.de
- Implement map resize (FATE#302007)
- Handle cciss devices correctly (bnc#419123)
* Wed Sep 24 2008 ro@suse.de
- use udevadm info instead of udevinfo
* Wed Sep  3 2008 hare@suse.de
- Merge in fixes from upstream:
  * Add IBM IPR to hardware table (bnc#419086)
  * Add IBM DS4300 to hardware table
  * Fix settings for scsi_id changes
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Thu Aug 28 2008 ro@suse.de
- fix init scripts
* Wed Jul 23 2008 hare@suse.de
- Update to version 0.4.8
- Include changes from SLES10
- Include mkinitrd scriptlets
* Wed May 28 2008 hare@suse.de
- Calculate correct partition offset in kpartx (bnc#394658)
* Fri May  9 2008 hare@suse.de
- Fixup kpartx rules (bnc#387667)
* Tue Apr 29 2008 hare@suse.de
- Merge in fixes from upstream
- Merge fixes from SLES10 SP2
* Wed Sep 19 2007 hare@suse.de
- Fixup generated dm_linear udev rules (#218122)
* Thu Aug 30 2007 hare@suse.de
- Rework dm_linear; udev rules should only be
  created if the feature was activated (#302422)
* Fri Aug 10 2007 hare@suse.de
- Implement dm_linear (#218122)
* Thu Aug  2 2007 hare@suse.de
- Merge in latest fixes from upstream
- Remove local patches; merge with upstream
- Fix kpartx handling of extended partitions
- Use underscores for partition names (#293792)
* Mon May 21 2007 hare@suse.de
- Rework udev handling
- Split off kpartx package
* Mon May 14 2007 hare@suse.de
- Merge in latest fixes from upstream
- Add all SuSE specific files to git repository.
* Fri May 11 2007 hare@suse.de
- Include latest changes from upstream
- Remove libsysfs (242766)
- Handle extended partitions for kpartx
* Mon Dec  4 2006 dmueller@suse.de
- don't build as root
* Fri Nov 17 2006 hare@suse.de
- integrate upstream fixes
- update udev rule for YaST2 dmraid support (217807])
* Mon Nov  6 2006 hare@suse.de
- Really fixup udev rule (216167).
* Fri Oct 20 2006 ro@suse.de
- make it build
* Mon Sep 25 2006 hare@suse.de
- update to latest fixes from git tree
- remove fixes integrated in upstream
- fixup udev rule (#203688)
* Wed Sep 13 2006 ro@suse.de
- use device-mapper-devel in BuildRequires
* Thu Aug 31 2006 hare@suse.de
- include latest fixes from git tree
- update kpartx_id and udev rules to work
  with dmraid.
- Fix return value for multipath -l
* Thu Aug 17 2006 ro@suse.de
- workaround problem in git-patch
  normal patch can't do a "rename", so copy file first
* Tue Jul 11 2006 hare@suse.de
- Update to official version 0.4.7
- Refactor git update to apply to 0.4.7
* Wed Jun 28 2006 hare@suse.de
- Remove blacklisting of dasd device node,
  use product_blacklist instead (#188688)
* Mon Jun 12 2006 hare@suse.de
- Add 72-multipath-compat.rules to create 'by-name'
  symlink again for compability (#183663)
* Fri Jun  2 2006 hare@suse.de
- Merge in fixed from upstream
  - Set device-mapper name correctly (#181127)
* Thu Jun  1 2006 hare@suse.de
- Merge in fixes from upstream
  - Fixup aliasing handling
  - Fix string length in pp_alua
- Use correct regexp patterns for hwtable (#177842)
- Fixup 71-multipath.rules to work correctly with the
  updated device-mapper online/offline events (#176516 - LTC23961)
- Add kpartx_id for the updated 71-multipath.rules
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Tue May  2 2006 hare@suse.de
- Merge in fixes from upstream
  - Merged local patches
  - Added hds_modular prioritizer
- Remove merged patches
- Allow for setting of maximum number of open files (#149979)
- Implement 'stop' for init scripts
* Mon Apr 10 2006 hare@suse.de
- Lowering priority for pp_tpc
- Split off DS6000 to fixup priority handler (#161347)
* Wed Apr  5 2006 hare@suse.de
- Disable debug messages in pp_tpc.
* Wed Mar 29 2006 hare@suse.de
- Explicitely create partitions at boot time (#159927)
* Thu Mar 23 2006 hare@suse.de
- Add hwtable entry for IBM 3526.
* Tue Mar 14 2006 hare@suse.de
- Fix another typo in mpath_id.
* Tue Mar 14 2006 hare@suse.de
- Fix typo in mpath_id.
* Mon Mar 13 2006 hare@suse.de
- Fix autobuild warnings.
- Include some minor fixed from upstream.
* Thu Mar  9 2006 hare@suse.de
- Add mpath_id program to call kpartx only on multipathed
  devices (#149995 - LTC21557).
- Include latest fixes from upstream.
* Wed Feb  8 2006 hare@suse.de
- Add device blacklisting (#85778)
- Further manpage installation fixes (#146179, #147053, #147911)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hare@suse.de
- Fix manpage installation.
* Tue Jan 17 2006 hare@suse.de
- Include latest git fixes
- Remove old patches which are now upstream
- Add new hwtable entry for shark (#142176)
* Fri Dec 16 2005 hare@suse.de
- Fix dependencies for /etc/init.d/boot.multipath
- Fix kpartx rules to generate proper partition names.
* Wed Dec  7 2005 hare@suse.de
- Update to multipath-tools-0.4.6
- Include latest git fixes
- Port patches from SLES9 SP3
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Mon Sep  5 2005 matz@suse.de
- Fix broken usage of self-defined syscall [#114933].
* Fri Aug 26 2005 hare@suse.de
- Fix kpartx DASD partition support
* Thu Aug  4 2005 hare@suse.de
- Add 'directio' path checker
- Add support for S/390 DASD (PAV enablement).
- Update to package from SLES9
* Thu Jun 23 2005 lmb@suse.de
- LUs with a WWN containing "fd" were blacklisted (#93562).
* Thu Jun 16 2005 lmb@suse.de
- Remove stray newline character from /dev/disk/by-name/ entries
  (#85798, #86763)
- Clear /dev/disk/by-name/ on boot. (#85978)
- scsi_id now handles EMC Symmetrix; remove work-around for #86760.
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Mon Jun 13 2005 ro@suse.de
- neededforbuild: udev -> sysfsutils
* Tue Jun  7 2005 lmb@suse.de
- Import fixes from upstream.
- Hardware table updates for IBM ESS and EMC CX (#81688).
- Reinstate paths correctly after failure/restore cycle (#85781,
  [#86444]).
- Create map names again and fix segfault in devmap_name (#85798).
* Tue May 24 2005 hare@suse.de
- Fix segmentation fault with EMC Symmetrix (#85614).
- Update EMC Symmetrix entry in hwtable.
* Mon May 23 2005 hare@suse.de
- Add hwtable entry for IBM DS6000. (#63903)
- Do a rescan for devices if multipath command line option is set.
* Fri May 20 2005 hare@suse.de
- Fix devmap_name to use mapname and return proper status (#84748).
* Thu May 12 2005 lmb@suse.de
- Don't complain about default prio callout command (#81695).
- Reflect recent changes in boot.multipath as well as multipathd init
  scripts.
- Actually fail paths when they are detected to be failed by multipathd
  (#81679).
- killproc/startproc/checkproc can't be used with multipathd because of
  the way the daemon switches to its own namespace (#80443).
* Mon May  9 2005 hare@suse.de
- Use proper path checker for SGI TPC arrays.
- Update hwtable entries for SGI TP9400 and SGI TP9500.
- Write correct PID file (#80443).
* Mon Apr 25 2005 lmb@suse.de
- Update to 0.4.4: pp_alua now licensed as GPL (#78628).
- multipath-tools-oom-adj.patch: oom_adj to a valid value.
* Thu Apr 21 2005 lmb@suse.de
- Update to 0.4.4-pre18 which fixes the multipathd to initialize
  correctly in the absence of a configuration file (79239).
* Wed Apr 20 2005 lmb@suse.de
- Put multipath cache back into /dev because /var might not be mounted.
- Correct hwtable entry SGI TP9400, TP9500 and IBM 3542.
* Wed Apr 20 2005 lmb@suse.de
- Update to 0.4.4-pre16
- Build against device-mapper.1.01.xx correctly.
* Tue Apr 19 2005 lmb@suse.de
- Build w/o device-mapper update again.
* Mon Apr 18 2005 lmb@suse.de
- Update to 0.4.4-pre14
- Build versus device-mapper-1.01.01 to prevent deadlocks in
  kernel-space.
- Fix devmap_name to work with udev.
- Fix startup of multipathd w/o configuration file present.
* Fri Apr 15 2005 lmb@suse.de
- Add path priority checker for EMC CLARiiON and make necessary
  adjustments so that it gets called by default (#62491).
- Set the default udev dir to '/dev'
* Fri Apr 15 2005 hare@suse.de
- Fix to allocate default strings (#78056)
- Fix default entry for TPC9500.
* Wed Apr 13 2005 hare@suse.de
- Added pp_alua path priority checker.
- Update to multipath-tools-0.4.4-pre12.
* Mon Apr 11 2005 hare@suse.de
- Update to multipath-tools-0.4.4-pre10.
* Fri Apr  8 2005 hare@suse.de
- Update multipath to handle only true multipath devices (#62491).
- Update kpartx to use the device mapper target name if available.
- Add boot.multipath script for early set up of multipath targets.
* Thu Mar 31 2005 hare@suse.de
- Update devmap_name to select targets by table type (#62493).
* Tue Jan 25 2005 lmb@suse.de
- Update to 0.4.2 and fix some bugs + add support for the extended DM
  multipath kernel module. (#47491)
* Thu Nov 11 2004 hare@suse.de
- Fix bugs to make it work on S/390 (#47491).
* Fri Nov  5 2004 hare@suse.de
- Update to version 0.3.6 (#47491).
- Fix multipath init script
- Install configuration file example.
- Install multipathd in /sbin instead of /usr/bin.
* Tue Jul 20 2004 fehr@suse.de
- updated README mp-tools-issues.pdf (see #40640)
* Wed Jun  9 2004 fehr@suse.de
- added pdf with README to package (see #40640)
* Thu Jun  3 2004 fehr@suse.de
- updated to version 0.2.1
- removed patches zero-currpath.patch and rm-newline-in-name.patch
  already contained in 0.2.1
* Thu Jun  3 2004 fehr@suse.de
- added patch zero-currpath.patch (see bugzilla #40640)
* Wed May 26 2004 uli@suse.de
- fixed to build on s390x
* Wed May 26 2004 fehr@suse.de
- added patch rm-newline-in-name.patch (see bugzilla #40640)
* Tue May 25 2004 fehr@suse.de
- created initial version of a SuSE package from version 0.2.0 of
  multipath tools
